﻿using System;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Markup;
using System.Windows.Media;

namespace XamlCruncherSL
{
    public partial class Page : UserControl
    {
        static readonly Brush okBrush = new SolidColorBrush(Colors.Black);
        static readonly Brush errorBrush = new SolidColorBrush(Colors.Red);

        public Page()
        {
            InitializeComponent();

            editingTextBox.Text =
                "<UserControl xmlns=\"http://schemas.microsoft.com/winfx/2006/xaml/presentation\"\r\n" +
                "             xmlns:x=\"http://schemas.microsoft.com/winfx/2006/xaml\">\r\n" +
                "    <TextBlock Text=\"Hello, Silverlight!\"\r\n" +
                "               HorizontalAlignment=\"Center\"\r\n" +
                "               VerticalAlignment=\"Center\"\r\n" +
                "               Foreground=\"Blue\"\r\n" +
                "               FontSize=\"48\"\r\n" +
                "               FontStyle=\"Italic\" />\r\n" +
                "</UserControl>\r\n";

            CreateObjectFromXaml(editingTextBox.Text);
        }

        void OnEditingTextChanged(object sender, TextChangedEventArgs args)
        {
            CreateObjectFromXaml(editingTextBox.Text);
        }

        void CreateObjectFromXaml(string str)
        {
            object obj;

            try
            {
                obj = XamlReader.Load(str);
            }
            catch (Exception exc)
            {
                statusTextBlock.Text = exc.Message.ToString();
                editingTextBox.Foreground = errorBrush;
                return;
            }

            if (obj == null)
            {
                statusTextBlock.Text = "NULL object";
                editingTextBox.Foreground = errorBrush;
                return;
            }

            statusTextBlock.Text = "OK";
            editingTextBox.Foreground = okBrush;

            if (obj is UIElement)
            {
                destinationElement.Child = obj as UIElement;
            }
            else
            {
                TextBlock txtblk = new TextBlock();
                txtblk.Text = obj.GetType().ToString();
                destinationElement.Child = txtblk;
            }
        }

        void OnEditingSelectionChanged(object sender, RoutedEventArgs e)
        {
            int index = editingTextBox.SelectionStart;
            int length = editingTextBox.SelectionLength;
            string str = GetSelectionText(index);

            if (length > 0)
            {
                str += " - " + GetSelectionText(index + length);
            }

            positionTextBlock.Text = str;
        }

        string GetSelectionText(int index)
        {
            int line, col;
            editingTextBox.GetPositionFromIndex(index, out line, out col);
            return String.Format("Line {0} Col {1}", line + 1, col + 1);
        }
    }
}
